import React, {
  useCallback,
  useEffect,
  useMemo,
  useRef,
  useState,
} from 'react';
import Cookies from 'js-cookie';
import { Anchor, Button, Popover, Radio, Result, Spin } from 'antd';

import classNames from 'classnames';
import { dom } from 'kit_utils';
import { connect } from 'react-redux';
// import { renderRoutes } from 'react-router-config';
import { useHistory } from 'react-router-dom';
import { useMountedState } from 'react-use';

import {
  LeftOutlined,
  MenuFoldOutlined,
  LoadingOutlined,
} from '@ant-design/icons';
import ProLayout, { getPageTitle } from '@ant-design/pro-layout';
import { getMatchMenu } from '@umijs/route-utils';
import pkg from '../../package.json';
import RightContent from '../components/GlobalHeader/RightContent';
import { Panel } from '../components/SliderPanel';
import { actionCreators } from '../containers/App/store';
import Authorized from '../utils/Authorized';
import isProd from '../utils/env';
import { findPathByLeafId, getBaseName } from '../utils/utils';
import SecurityLayout from './SecurityLayout';
import Site from './Site';
import styles from './UserLayout.less';
import defaultSetting from '../../config/defaultSetting';
// import Login from '../pages/user/login/login';
const antIcon = <LoadingOutlined style={{ fontSize: 12 }} spin />;

const baseURI = isProd
  ? window.location.origin
  : `http://${window.location.hostname}:3020`;
const optionsWith = [
  { label: '按站点', value: 'site' },
  { label: '按城市', value: 'city' },
];
const noMatch = (
  <Result
    status={403}
    title="403"
    subTitle="Sorry, you are not authorized to access this page."
    extra={<Button type="primary">Go Login</Button>}
  />
);

const renderIcon = (icon, size, alias) => {
  const transformIcon = () => icon.replace(/\s*/g, '');
  const url = window.globalConfig.transformDevAssetsBaseURL(transformIcon())
  return (
    <img
      src={url}
      style={{ width: `${size}px`, height: `${size}px`, opacity: '0.8' }}
      alt=""
    />
  );
};

const menuExtraRender = currentRoutes => {
  // eslint-disable-next-line react-hooks/rules-of-hooks
  const [toggleSystem, setToggleSystem] = useState(false);
  return {
    render: ({ collapsed }) => {
      if (currentRoutes) {
        const iconURL =
          currentRoutes && currentRoutes.extData && currentRoutes.extData.icon
            ? window.globalConfig.transformDevAssetsBaseURL(
                currentRoutes.extData.icon,
              )
            : '';
        return (
          <>
            <Spin
              spinning={currentRoutes.extData && !currentRoutes.extData.icon}
            >
              {iconURL && (
                <a
                  style={{ display: 'flex', alignItems: 'center' }}
                  onClick={() => setToggleSystem(!toggleSystem)}
                >
                  <img
                    src={iconURL}
                    style={{ width: '20px', height: '20px' }}
                    alt=""
                  />

                  <span
                    style={{
                      margin: '0 2px 0 7px',
                      textOverflow: 'ellipsis',
                      overflow: 'hidden',
                      whiteSpace: 'nowrap',
                      color: 'rgba(255, 255, 255, 0.65)',
                      fontSize: '14px',
                    }}
                  >
                    {currentRoutes && currentRoutes.name}
                  </span>
                  <MenuFoldOutlined
                    style={{ color: '#888', marginLeft: '10px' }}
                  />
                </a>
              )}
            </Spin>
          </>
        );
      }
      return null;
    },
    toggleSystem,
    onClose: () => setToggleSystem(!toggleSystem),
  };
};
const HOT = ['HOT', '县', '市', 'New'];
const StationsItem = (item, action) => {
  const changeGroup = (event, data) => {
    action.changeGroup && action.changeGroup(event, data);
  };
  return (
    <li
      key={item.groupID}
      style={{ marginRight: `${item.style.marginRight}px` }}
    >
      <a
        className={classNames(styles.city_select, styles.showTip)}
        title={item.city}
        index={item.promoteIndex}
        style={{ fontSize: '13px' }}
        onClick={event => changeGroup(event, item)}
      >
        {item.groupName}
        {item.promoteTip && HOT.includes(item.promoteTip) && (
          <div title={`${item.promoteTip}`}>{item.promoteTip}</div>
        )}
      </a>
    </li>
  );
};

const Stations = props => {
  const data = props.data.stations;
  const [targetOffset, setTargetOffset] = useState(undefined);
  const cityPane = useRef(null);
  const cityContent = useRef(null);
  const [defaultTab, setDefaultTab] = useState('site');
  useEffect(() => {
    setTargetOffset(cityPane.current.clientHeight / 2);
  }, []);

  const handleClick = (event, link) => {
    event.preventDefault();
  };

  const handleTabChange = event => {
    setDefaultTab(event.target.value);
  };
  return (
    <>
      <div className={styles.focusStations}>
        <ul>
          {Array.isArray(data)
            ? data.map(item => StationsItem(item, props.action))
            : null}
        </ul>
      </div>
      <Radio.Group
        options={optionsWith}
        optionType="button"
        buttonStyle="solid"
        size="small"
        value={defaultTab}
        onChange={handleTabChange}
        style={{ marginTop: '6px' }}
      />
      <div style={{ maxWidth: '520px', position: 'relative' }}>
        {defaultTab === 'site' ? (
          <div
            className={classNames(styles.city_pane, styles.station_container)}
            ref={cityPane}
          >
            <Anchor
              affix={false}
              onClick={handleClick}
              targetOffset={targetOffset}
              getContainer={() => cityContent.current}
            >
              <ul className={styles.py}>
                {props.data &&
                  props.data.siteCityList &&
                  props.data.siteCityList.letters}
              </ul>
              <div
                className={styles.cityContent}
                style={{ height: '335px' }}
                ref={cityContent}
              >
                {props.data &&
                  props.data.siteCityList &&
                  props.data.siteCityList.content}
              </div>
            </Anchor>
          </div>
        ) : (
          <div className="city_pane city_container">
            {props.data.citySelector}
          </div>
        )}
        <Spin spinning={props.loading} tip="加载中" />
      </div>
    </>
  );
};

const renderTitle = ({
  title,
  action,
  data,
  loading,
  setLoading,
  collapsed,
  fixedHeader,
  config,
}) => {
  // eslint-disable-next-line react-hooks/rules-of-hooks,no-debugger
  // eslint-disable-next-line react-hooks/rules-of-hooks
  const [visible, setVisible] = useState(false);
  const header = document.querySelector('.ant-pro-fixed-header');
  let marginLeft = '148px';
  const DEFAULT_MIXIN_WIDTH = 48;
  if (header && fixedHeader) {
    const documentWidth = document.body.clientWidth;
    if (documentWidth === header.offsetWidth && !collapsed) {
      marginLeft = '148px';
    } else {
      /* eslint-disable */
      const deltWidth = document.body.clientWidth - header.offsetWidth;
      marginLeft = collapsed
        ? '0px'
        : deltWidth === DEFAULT_MIXIN_WIDTH
        ? `100px`
        : `${deltWidth}px`;
    }
  }
  let loaded = !!(data && !data.stations ||  (Array.isArray(data.weathers) && data.weathers.length === 0));
  if(config && config.userInfo && config.userInfo.site === "") {
    loaded = false;
  }
  return  (
      <>
        <span className={styles['header-title']} style={{ marginLeft }}>
          {title}
        </span>
        <Spin indicator={antIcon} spinning={loaded} size="small" style={{marginLeft: '10px'}} tip="加载中" wrapperClassName={styles.spinLoadding}>
          <div className={styles.cityContent}>
            <Popover
              placement="bottomLeft"
              trigger="click"
              content={
                <Stations
                  data={data}
                  action={action}
                  loading={loading}
                  setLoading={setLoading}
                />
              }
              arrowPointAtCenter
              overlayClassName={styles.stationsWrapper}
              onVisibleChange={visible => setVisible(visible)}
            >
              {Array.isArray(data.stations) && data.stations.length > 0 ? (
                <span className={styles.siteName}>
                <img src="https://panda-water.cn/web4/assets/images/depart.svg" />
                <span>{data.currentStationName}</span>
                <img
                  src="https://panda-water.cn/web4/assets/images/下.svg"
                  style={{
                    transform: !visible ? `rotate(0deg)` : `rotate(180deg)`,
                  }}
                />
              </span>
            ) : null}
          </Popover>
          {data.weathers && Object.keys(data.weathers).length > 0 ? (
            <span
              className={styles.weatcher}
              style={{
                borderLeft:
                  data.stations.length === 0 ? '0px' : '1px solid #aaaaaa',
              }}
            >
              <img src={data.weathers && data.weathers.icon} />
              <span>{data.weathers && data.weathers.text}</span>
            </span>
            ) : null}
          </div>
        </Spin>

      </>
  );
};
const BasicLayout = props => {
  /* eslint-disable no-unused-vars */
  const {
    children,
    settings,
    location = {
      pathname: '/',
    },
  } = props;
  const basename = getBaseName();
  const history = useHistory();
  const [currentRoutes, setCurrentRoutes] = useState([]);
  const [collapse, setCollapse] = useState(false);
  const [loading, setLoading] = useState(true);
  const [cityData, setCityData] = useState({});
  const [pageLoading, setPageLoading] = useState(true);
  const [siteLoading, setSiteLoading] = useState(false);
  const [complexCollapsed, setComplexCollapsed] = useState(false);
  const isMounted = useMountedState();
  const [siteAction, setSiteAction] = useState(
    () => new Site(props, setSiteLoading),
  );

  // useEffect(() => {
  //   setCurrentRoutes(props.route.routes[props.currentMenuIndex]);
  // }, [props.route, props.currentMenuIndex]);

  useEffect(() => {
    props.updatePathname(props.location.pathname);
  }, []);

  const extraRender = menuExtraRender(currentRoutes);
  let clearTime = null;
  //
  // useEffect(() => {
  //   setTimeout(() => {
  //     if (isMounted) setPageLoading(!pageLoading);
  //   }, 2000);
  // }, []);

  useEffect(() => {
    const config = findPathByLeafId(
      `${props.location.pathname}`,
      [currentRoutes],
      '',
      'path',
    );
    config && config.parent && props.updateOpenKeys([config.parent.path]);
    if (config && config.level <= 3) {
      props.updatePathname(config.key);
      props.updateSelectedKeys(config.key);
    } else if (config) {
      const { name, path, parent } = config;
      // setPathname(parent.key);
      props.updatePathname(parent.key);
      props.updateSelectedKeys(parent.path);
      props.updateComplexPathName(path);
      const findDeepLevelConfig = findPathByLeafId(
        parent.path,
        currentRoutes.routes,
        '',
        'path',
      );
      props.updateComplexConfig(findDeepLevelConfig);
      setCollapse(true);
      history.push(config.path);
    }
  }, [props.location.pathname, currentRoutes]);

  // useEffect(() => {
  //   setLoading(true);
  //
  //
  //   debugger
  //
  //     setTimeout(() => {
  //       debugger
  //       const routes = props.route.routes;
  //       if(routes.length > 0 && props.currentMenuIndex !== -1) {
  //         if(currentRoutes && !currentRoutes.routes) {
  //           setCurrentRoutes(props.route.routes[props.currentMenuIndex]);
  //           setLoading(false);
  //         }
  //
  //       }
  //
  //     }, 400)
  //
  // }, [props.currentMenuIndex, props.route]);
  //
  useEffect(() => {
    setLoading(true);
    clearTime = setTimeout(() => {
      if(props.currentMenuIndex !== -1) {
        setCurrentRoutes(props.route.routes[props.currentMenuIndex]);
        setLoading(false);
      }
    }, 400);
    return () => clearTimeout && clearTimeout(clearTime);
  }, [props.currentMenuIndex]);





  // useEffect(() => {
  //   debugger
  //   // const menu = props.menu.filter(item => !item.hideInMenu);
  //   setLoading(true);
  //   setCurrentRoutes([]);
  //   clearTime = setTimeout(() =>  {
  //     debugger
  //     // props.route && (props.route.routes.filter(item => !item.hideInMenu || item.path !== '/404' || item.path !== '/500')).length === 0 && setLoading(true);
  //     if(props.route && props.route.routes.length > 0 && props.route.routes[props.currentMenuIndex].path !== currentRoutes.path) {
  //       setCurrentRoutes(props.route.routes[props.currentMenuIndex]);
  //       setLoading(false);
  //     }
  //   }, 400);
  //   return () => clearTimeout && clearTimeout(clearTime);
  // }, [props.route]);

  useEffect(() => {
    siteAction.setGlobalConfig(props.global);
    if (!Cookies.get('token')) {
      history.replace(`/user/login?client=${props.global.get('client')}`);
      return;
    }
    if(props.global && props.global.userInfo && props.global.userInfo.token !== null && props.global.userInfo.loginName && Object.keys(cityData).length === 0) {
      siteAction.getCityStationsForUser().then(res => {
        setCityData(res);
      });
    }
  }, [props.global]);

  useEffect(() => {
    window.share.event.on('updateSite', res => setCityData(res));
    return () => window.share.event.removeAllListeners('updateSite')
  }, []);

  useMemo(() => {
    window.share.event.on('listenerRemoveTab', () => {
      props.updateSelectedKeys(`/civweb4/?client=${props.global.get('client')}`);
      props.updatePathname(`/civweb4/?client=${props.global.get('client')}`);
      history.push(`/civweb4/?client=${props.global.get('client')}`);
    });
    window.share.event.removeAllListeners('listenerRemoveSigleTab');
  }, [props.pathname]);

  useMemo(() => {
    window.share.event.on(' `', url => {
      const config = findPathByLeafId(
        `${props.location.pathname}`,
        [currentRoutes],
        '',
        'path',
      );
      if (config) {
        props.updatePathname(config.key);
        props.updateSelectedKeys(config.key);
      }
    });
    window.share.event.removeAllListeners('listenerRemoveSigleTab');
  }, []);

  // const updateSettings = config => {
  //   props.updageSetting && props.updageSetting(config);
  // };
  const menuDataRef = useRef([]);
  const authorized = useMemo(() => {
    const isHash = window.location.hash !== '';
    const path = isHash
      ? `${props.location.pathname}${window.location.hash}`
      : `${props.location.pathname}`;
    return (
      getMatchMenu(path || '/', menuDataRef.current).pop() || {
        path,
      }
    );
  }, [location.pathname]);
  const handleSelectedKey = item => {
    const config = findPathByLeafId(item.path, currentRoutes.routes, '', 'path');
    props.updateComplexConfig({});
    props.updateComplexPathName(null);
    if (config && config.routes && config.routes.length > 0) {
      props.updateComplexConfig(config);
      props.updateComplexPathName(config.routes[0].path);
      history.push(config.routes[0].path);
    } else {
      history.push(config.path);
    }
    props.updatePathname(item.key);
    props.updateSelectedKeys(`${item.key}`);
    extraRender.onClose();
    // history.push(item.key);
  };

  const handleLogo = event => {
    props.global.get('userInfo.site') ? (history.push(`/industry`)) : null;
  };

  const transformPopupMenu = useCallback(key => {
    if (key.length > 0) {
      const element = document.getElementById(`${key[0]}$Menu`);
      const len = element ? element.children.length : 0;
      if (len >= 6) {
        dom.addClass(element, styles['popup-menu-flex']);
      }
    }
  });

  const others = {
    history: props.history,
    location: props.location,
    match: props.match,
    route: props.menu,
    fixedHeader: true,
    fixSiderbar: true,
    collapsed: collapse,
  };

  const headerContentRender = renderTitle({
    title: props.global.get('title'),
    action: siteAction,
    data: cityData,
    loading: siteLoading,
    setLoading: setSiteLoading,
    collapsed: collapse,
    fixedHeader: others.fixedHeader,
    config: props.global,
  });

  const menuComplexDataRender = menuList =>
    menuList.map(item => {
      const localItem = {
        ...item,
        hideInMenu: false,
        routes: item.routes ? item.routes : undefined,
      };
      return localItem;
    });

  const transformComplexSideWidth = () => {
    const complexConfig = props.complexConfig.toJS
      ? props.complexConfig.toJS()
      : props.complexConfig;
    let defaultWidth = '150px';
    if (complexCollapsed) {
      return defaultWidth;
    }
    if (
      complexConfig &&
      Object.keys(complexConfig).length > 0 &&
      complexConfig.level === 3
    ) {
      defaultWidth = 150;
    } else {
      defaultWidth = 0;
    }
    return defaultWidth;
  };

  const forceRender = () => {
    if (
      props.location.pathname ===
      decodeURIComponent(
        window.location.pathname.split(pkg.name.toLocaleLowerCase())[1],
      )
    ) {
      window.share.event.emit('trigger:route');
    }
  };

  const title = getPageTitle({
    title: props.global && props.global.get('title') || defaultSetting.title
  });

  const logo = props.global.get('bannerLogo') ?window.globalConfig.transformDevAssetsBaseURL(props.global.get('bannerLogo')): defaultSetting.logo;
  const renderComplexLayout = children => {
    const complexConfig = props.complexConfig.toJS
      ? props.complexConfig.toJS()
      : props.complexConfig;
    return (
      <ProLayout
        logo={false}
        title={title}
        headerRender={false}
        rightContentRender={() => null}
        collapsedButtonRender={false}
        menuHeaderRender={false}
        footerRender={false}
        className={styles.complexLayout}
        location={{
          pathname: props.complexPathName,
        }}
        route={{
          routes:
            (complexConfig &&
              complexConfig.routes &&
              menuComplexDataRender(complexConfig.routes)) ||
            [],
        }}
        menuItemRender={(menuItemProps, defaultDom) => {
          if (menuItemProps.isUrl || !menuItemProps.path) {
            return defaultDom;
          }
          return <a to={menuItemProps.path}>{defaultDom}</a>;
        }}
        menuProps={{
          onClick: ({ item, key, keyPath, domEvent }) => {
            const config = findPathByLeafId(key, [complexConfig], '', 'key');
            props.updateComplexPathName(key);
            history.push(config.path);
          },
        }}
        collapsed={complexCollapsed}
        navTheme="light"
        siderWidth={transformComplexSideWidth()}
        style={{
          height: '400px'
        }}
      >
        {complexConfig && Object.keys(complexConfig).length > 0 ? (
          <span
            className={styles.complexCollapse}
            onClick={() => setComplexCollapsed(!complexCollapsed)}
          >
            <span className={styles.collapsed}>
              <LeftOutlined />
            </span>
          </span>
        ) : null}
        {children}
      </ProLayout>
    );
  };

  const handlerCollapsed = collapse => {
    setCollapse(collapse);
    if (!collapse) {
      const config = findPathByLeafId(
        `${props.location.pathname}`,
        [currentRoutes],
        '',
        'path',
      );
      // fix: 目前菜单限制只支持两级
      if (config && config.parent) {
        const parentConfig = findPathByLeafId(
          config.parent.path,
          [currentRoutes],
          '',
          'path',
        );
        parentConfig &&
          parentConfig.parent &&
          props.updateOpenKeys([parentConfig.parent.path, config.parent.path]);
      }
    }
  };

  const renderSiderMenu = (menuItemProps, defaultDom) => {
    if (collapse) {
      return (
        <>
          {renderIcon(menuItemProps.extData && menuItemProps.extData.icon, 17, menuItemProps.alias)}
          <div
            className={`ant-pro-menu-item ${styles.shortName} ${
              styles.minixName
            }`}
          >
            {menuItemProps &&
            menuItemProps.extData &&
            menuItemProps.extData.shortName
              ? menuItemProps.extData.shortName
              : menuItemProps.name}
          </div>
          <div
            className={`ant-pro-menu-item ${styles.shortName} ${
              styles.popverName
            }`}
          >
            {menuItemProps.name}
          </div>
        </>
      );
    }
    return (
      <>
        {renderIcon(menuItemProps.extData && menuItemProps.extData.icon, 17, menuItemProps.alias)}
        {defaultDom}
      </>
    );
  };
  const { openKeys } = props;
  // const filterMenu = props.menu.filter(item => !item.hideInMenu)
  return (
    <SecurityLayout loading updateCurrentIndex={props.updateCurrentIndex}>
      <ProLayout
        logo={logo}
        siderWidth="145px"
        title={title}
        onCollapse={collapse => handlerCollapsed(collapse)}
        onMenuHeaderClick={event => handleLogo(event)}
        menuExtraRender={props.menu.length > 0 ? extraRender.render : null}
        rightContentRender={() => <RightContent {...props} />}
        headerContentRender={() => headerContentRender}
        menu={{
          loading,
        }}
        location={props.pathname}
        locale
        menuDataRender={() => currentRoutes && currentRoutes.routes}
        menuItemRender={(menuItemProps, defaultDom) => {
          if (menuItemProps.isUrl || !menuItemProps.path) {
            return (
              <a
                className={styles.menuItemLink}
                href={menuItemProps.href}
                target={menuItemProps.target}
                title={menuItemProps.name}
              >
                {!collapse && (
                  <>
                    {renderIcon(
                      menuItemProps.extData && menuItemProps.extData.icon,
                      17,
                      menuItemProps.alias,
                    )}
                    <span className="ant-pro-menu-item">
                      <span className="ant-pro-menu-item-title">
                        {menuItemProps.name}
                      </span>
                    </span>
                  </>
                )}
                {collapse && renderSiderMenu(menuItemProps, defaultDom)}
              </a>
            );
          }
          return (
            <a
              to={menuItemProps.path}
              className={styles.menuItemLink}
              onClick={() => history.push(menuItemProps.path)}
              title={menuItemProps.name}
            >
              {renderSiderMenu(menuItemProps, defaultDom)}
            </a>
          );
        }}
        subMenuItemRender={(menuItemProps, defaultDom) => (
          <>
            {renderIcon(
              menuItemProps.extData && menuItemProps.extData.icon,
              17,
               menuItemProps.alias,
            )}
            {collapse ? (
              <div className={`ant-pro-menu-item ${styles.shortName}`}>
                {menuItemProps.extData && menuItemProps.extData.shortName
                  ? menuItemProps.extData.shortName
                  : menuItemProps.name}
              </div>
            ) : (
              defaultDom
            )}
          </>
        )}
        openKeys={[...openKeys]}
        menuProps={{
          forceSubMenuRender: false,
          onClick: ({ item, key, keyPath, domEvent }) => {
            domEvent.persist();
            const keyField = key.indexOf('/') > -1 ? 'path' : 'key';
            const config = findPathByLeafId(key, currentRoutes.routes, '', keyField);
            props.updateComplexConfig({});
            props.updateComplexPathName(null);
            if (config && config.routes && config.routes.length > 0) {
              props.updateComplexConfig(config);
              props.updateComplexPathName(config.routes[0].path);
              history.push(config.routes[0].path);
            }
            props.updateSelectedKeys(key);
            props.updatePathname(key);
            forceRender();
          },
          onOpenChange: openKeys => {
            props.updateOpenKeys(openKeys.length > 0 ? openKeys : []);
            if (collapse) {
              transformPopupMenu(openKeys);
            }
          },
          selectedKeys: [props.selectedKeys],
          popupClassName: styles.menuPopover,
        }}
        postMenuData={menuData => {
          menuDataRef.current = menuData || [];
          return menuData || [];
        }}
        settings={defaultSetting}
        {...others}
      >
        <Spin
          spinning={props.microMounted}
          size="large"
          wrapperClassName={styles.loadding}
        >
          <Panel
            visible={extraRender.toggleSystem}
            keyboard
            onClose={extraRender.onClose}
            data={props.route.routes || []}
            currentMenuIndex={props.currentMenuIndex}
            onChange={index => props.updateCurrentIndex(index)}
            onSelect={item => handleSelectedKey(item)}
          />
          {/*noMatch={noMatch*/}
          {renderComplexLayout(
            <>
              <Authorized authority={authorized} {...props}>
                {children}
              </Authorized>
              <div id="micro-container" className="subapp-container" />
            </>,
          )}
        </Spin>

        {/*
          <SettingDrawer
            settings={props.settings}
            onSettingChange={config => updateSettings(config)}
            publicPath={`/${basename}/theme`}
          /> */}
      </ProLayout>
      {/*<div id="micro-container" className="subapp-container" />*/}
    </SecurityLayout>
  );
};
const mapStateToProps = state => ({
  global: state.getIn(['global', 'globalConfig']),
  settings: state.getIn(['global', 'defaultSetting']),
  collapsed: state.getIn(['global', 'collapsed']),
  menu: state.getIn(['global', 'menu']),
  currentMenuIndex: state.getIn(['global', 'currentMenuIndex']),
  flatMenu: state.getIn(['global', 'flatMenu']),
  authValidate: state.getIn(['global', 'authValidate']),
  pathname: state.getIn(['global', 'pathname']),
  selectedKeys: state.getIn(['global', 'selectedKeys']),
  openKeys: state.getIn(['global', 'openKeys']),
  complexConfig: state.getIn(['global', 'complexConfig']),
  complexPathName: state.getIn(['global', 'complexPathName']),
  microMounted: state.getIn(['global', 'microMounted']),
});
const mapDispatchToProps = dispatch => ({
  updageSetting(setting) {
    dispatch(actionCreators.updageSetting(setting));
  },
  updateConfig(config) {
    dispatch(actionCreators.getConfig(config));
  },
  updateCurrentIndex(index) {
    dispatch(actionCreators.updateCurrentIndex(index));
  },
  updateCollapsed(collapsed) {
    dispatch(actionCreators.updateCollapsed(collapsed));
  },
  updateAuthValidate(auth) {
    dispatch(actionCreators.updateAuthValidate(auth));
  },
  updatePathname(pathname) {
    dispatch(actionCreators.updatePathname(pathname));
  },
  updateSelectedKeys(keys) {
    dispatch(actionCreators.updateSelectedKeys(keys));
  },
  updateOpenKeys(keys) {
    dispatch(actionCreators.updateOpenKeys(keys));
  },
  updateComplexConfig(config) {
    dispatch(actionCreators.updateComplexConfig(config));
  },
  updateComplexPathName(pathname) {
    dispatch(actionCreators.updateComplexPathName(pathname));
  },
});
export default connect(
  mapStateToProps,
  mapDispatchToProps,
)(BasicLayout);
